garmi\_gui package
==================

.. automodule:: garmi_gui
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

garmi\_gui.control module
-------------------------

.. automodule:: garmi_gui.control
   :members:
   :undoc-members:
   :show-inheritance:

garmi\_gui.gui module
---------------------

.. automodule:: garmi_gui.gui
   :members:
   :undoc-members:
   :show-inheritance:
